summaryrefslogtreecommitdiffstats
path: root/ksquirrel/sq_imageloader.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'ksquirrel/sq_imageloader.cpp')
-rw-r--r--ksquirrel/sq_imageloader.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/ksquirrel/sq_imageloader.cpp b/ksquirrel/sq_imageloader.cpp
index 642c4c2..48b11cd 100644
--- a/ksquirrel/sq_imageloader.cpp
+++ b/ksquirrel/sq_imageloader.cpp
@@ -19,7 +19,7 @@
#include "config.h"
#endif
-#include <qfile.h>
+#include <tqfile.h>
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
@@ -34,7 +34,7 @@
SQ_ImageLoader * SQ_ImageLoader::m_instance = 0;
-SQ_ImageLoader::SQ_ImageLoader(QObject *parent) : QObject(parent), m_errors(0)
+SQ_ImageLoader::SQ_ImageLoader(TQObject *tqparent) : TQObject(tqparent), m_errors(0)
{
m_instance = this;
@@ -54,7 +54,7 @@ SQ_ImageLoader::~SQ_ImageLoader()
/*
* Try to determine image dimensions.
*/
-bool SQ_ImageLoader::tasteImage(const QString &path, int *w, int *h, SQ_LIBRARY *_lib)
+bool SQ_ImageLoader::tasteImage(const TQString &path, int *w, int *h, SQ_LIBRARY *_lib)
{
SQ_LIBRARY *lib;
int res;
@@ -73,7 +73,7 @@ bool SQ_ImageLoader::tasteImage(const QString &path, int *w, int *h, SQ_LIBRARY
return false;
// init...
- res = codeK->read_init(QString(QFile::encodeName(path)));
+ res = codeK->read_init(TQString(TQFile::encodeName(path)).ascii());
// error in init()!
if(res != SQE_OK)
@@ -107,7 +107,7 @@ bool SQ_ImageLoader::tasteImage(const QString &path, int *w, int *h, SQ_LIBRARY
* Try to load image and store a pointer to decoded image data in m_image. Aslo
* store information about the image in finfo.
*/
-bool SQ_ImageLoader::loadImage(const QString &pixPath, const SQ_CodecSettings::settings &sett, bool multi, int nomorethan)
+bool SQ_ImageLoader::loadImage(const TQString &pixPath, const SQ_CodecSettings::settings &sett, bool multi, int nomorethan)
{
SQ_LIBRARY *lib;
int res, current = 0, i, j;
@@ -141,7 +141,7 @@ bool SQ_ImageLoader::loadImage(const QString &pixPath, const SQ_CodecSettings::s
SQ_CodecSettings::applySettings(lib, sett);
// init...
- res = codeK->read_init(QString(QFile::encodeName(pixPath)));
+ res = codeK->read_init(TQString(TQFile::encodeName(pixPath)).ascii());
// error in init()!
if(res != SQE_OK)
@@ -247,13 +247,13 @@ void SQ_ImageLoader::cleanup(bool del)
}
/*
* Return decoded image as QImage.
*/
-QImage SQ_ImageLoader::image() const
+TQImage SQ_ImageLoader::image() const
{
- QImage image((unsigned char*)bits(), finfo->image[0].w, finfo->image[0].h, 32, 0, 0, QImage::LittleEndian);
+ TQImage image((unsigned char*)bits(), finfo->image[0].w, finfo->image[0].h, 32, 0, 0, TQImage::LittleEndian);
- // if the image has alpha channel, let QImage know it
+ // if the image has alpha channel, let TQImage know it
if(finfo->image[0].hasalpha)
image.setAlphaBuffer(true);
@@ -247,13 +247,13 @@ void SQ_ImageLoader::cleanup(bool del)
}
/*
- * Return decoded image as QImage.
+ * Return decoded image as TQImage.
*/